@@ -93,6 +93,15 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
     connection->statement_execute_non_select("SET DATESTYLE = 'ISO'");
     data_model = connection->statement_execute_select("SELECT version()");
   }
+  catch(const Gnome::Gda::ConfigError& ex)
+  {
+    //These errors are unusual.
+    //For instance, the PostgreSQL libgda provider could be missing,
+    //though we check for that at startup.
+    std::cerr << G_STRFUNC << 
+      ": ConfigError exception from Gnome::Gda::Connection::open_from_string(): " <<
+      ex.what();
+  }
   catch(const Glib::Error& ex)
   {
 #else
@@ -127,6 +136,15 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
         cnc_string, auth_string,
         Gnome::Gda::CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE);
     }
+    catch(const Gnome::Gda::ConfigError& ex)
+    {
+      //These errors are unusual.
+      //For instance, the PostgreSQL libgda provider could be missing,
+      //though we check for that at startup.
+      std::cerr << G_STRFUNC << 
+        ": ConfigError exception from Gnome::Gda::Connection::open_from_string(): " <<
+        ex.what();
+    }
     catch(const Glib::Error& ex)
     {}
 #else
@@ -523,10 +541,10 @@ std::string Postgres::get_path_to_postgres_executable(const std::string& program
 }
 
 
-Glib::ustring Postgres::port_as_string(int port_num)
+Glib::ustring Postgres::port_as_string(unsigned int port_num)
 {
   Glib::ustring result;
-  char* cresult = g_strdup_printf("%d", port_num);
+  char* cresult = g_strdup_printf("%u", port_num);
   if(cresult)
     result = cresult;
   g_free(cresult);
