@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "layoutitem_notebook.h"
+#include <libglom/data_structure/layout/layoutitem_notebook.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -52,6 +52,7 @@ LayoutItem_Notebook& LayoutItem_Notebook::operator=(const LayoutItem_Notebook& s
 
 Glib::ustring LayoutItem_Notebook::get_part_type_name() const
 {
+  //Note to translators: "Notebook" means a GtkNotebook-type widget.
   return _("Notebook");
 }
 
