@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "tableinfo.h"
+#include <libglom/data_structure/tableinfo.h>
 
 namespace Glom
 {
@@ -33,6 +33,7 @@ TableInfo::TableInfo()
 
 TableInfo::TableInfo(const TableInfo& src)
 : TranslatableItem(src),
+  HasTitleSingular(src),
   m_sequence(src.m_sequence),
   m_hidden(src.m_hidden),
   m_default(src.m_default)
@@ -42,7 +43,8 @@ TableInfo::TableInfo(const TableInfo& src)
 TableInfo& TableInfo::operator=(const TableInfo& src)
 {
   TranslatableItem::operator=(src);
-
+  HasTitleSingular::operator=(src);
+  
   m_sequence = src.m_sequence;
   m_hidden = src.m_hidden;
   m_default = src.m_default;
@@ -50,4 +52,5 @@ TableInfo& TableInfo::operator=(const TableInfo& src)
   return *this;
 }
 
+
 } //namespace Glom
