@@ -18,10 +18,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef GLOM_MODE_DESIGN_COMBOENTRY_BORDERWIDTH_H
-#define GLOM_MODE_DESIGN_COMBOENTRY_BORDERWIDTH_H
+#ifndef GLOM_MODE_DESIGN_COMBOENTRY_BORDERWIDTH_HH
+#define GLOM_MODE_DESIGN_COMBOENTRY_BORDERWIDTH_HH
 
-#include <gtkmm/comboboxentry.h>
+#include <gtkmm/combobox.h>
 #include <gtkmm/builder.h>
 
 #include <gtkmm/liststore.h>
@@ -29,7 +29,7 @@
 namespace Glom
 {
 
-class ComboEntry_BorderWidth : public Gtk::ComboBoxEntry
+class ComboEntry_BorderWidth : public Gtk::ComboBox
 {
 public:
   ComboEntry_BorderWidth(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
@@ -58,4 +58,5 @@ private:
 
 } //namespace Glom
 
-#endif // GLOM_MODE_DESIGN_COMBOENTRY_BORDERWIDTH_H
+#endif //GLOM_MODE_DESIGN_COMBOENTRY_BORDERWIDTH_HH
+
