@@ -21,6 +21,7 @@
 #ifndef WINDOW_PRINT_LAYOUT_EDIT_H
 #define WINDOW_PRINT_LAYOUT_EDIT_H
 
+#include <gtkmm/box.h>
 #include <libglom/data_structure/print_layout.h>
 #include <glom/print_layout/canvas_print_layout.h>
 #include <glom/mode_design/print_layouts/print_layout_toolbar.h>
@@ -29,10 +30,9 @@
 #include <gtkmm/window.h>
 #include <gtkmm/entry.h>
 #include <gtkmm/label.h>
-#include <gtkmm/box.h>
 #include <gtkmm/uimanager.h>
-//#include <gtkmm/toggleaction.h>
-#include <gtkmm/ruler.h>
+//TODO: #include <gtkmm/ruler.h>
+#include <glom/utility_widgets/gimpruler/gimpruler.h>
 #include <gtkmm/builder.h>
 
 namespace Glom
@@ -124,8 +124,8 @@ private:
   bool m_drag_preview_requested;
   Glib::RefPtr<CanvasLayoutItem> m_layout_item_dropping;
 
-  Gtk::VRuler* m_vruler;
-  Gtk::HRuler* m_hruler;
+  GimpRuler* m_vruler;
+  GimpRuler* m_hruler;
 
   //Main menu:
   Glib::RefPtr<Gtk::ActionGroup> m_action_group;
@@ -135,7 +135,7 @@ private:
 
   //Toolbar:
   Gtk::HandleBox* m_palette_handle_box; //TODO: The toolbar is already a HandleBox.
-  std::list<Gtk::TargetEntry> m_drag_targets;
+  std::vector<Gtk::TargetEntry> m_drag_targets;
   PrintLayoutToolbar m_toolbar;
   
   //Context menu for clicking on empty space on the canvas:
